/// <reference types="node" />
import PNGDiffer from '../interfaces/png-differ';
import Browser from '../interfaces/browser';
import FileSystem from '../interfaces/file-system';
import PNGProcessor from '../interfaces/png-processor';
import Screenshotter, { ScreenshotOptions } from '../interfaces/screenshotter';
export declare type MugshotIdenticalResult = {
    matches: true;
    expectedPath: string;
    expected: Buffer;
};
export declare type MugshotDiffResult = {
    matches: false;
    expected: Buffer;
    actual: Buffer;
    diff: Buffer;
    expectedPath: string;
    actualPath: string;
    diffPath: string;
};
export declare type MugshotResult = MugshotIdenticalResult | MugshotDiffResult;
export declare type MugshotSelector = string;
interface MugshotOptions {
    fs?: FileSystem;
    pngDiffer?: PNGDiffer;
    pngProcessor?: PNGProcessor;
    screenshotter?: Screenshotter;
    /**
     * If set to true `Mugshot.check` will pass if a baseline is not
     * found and it will create the baseline from the screenshot it
     * takes.
     */
    createMissingBaselines?: boolean;
    /**
     * When set to true Mugshot will overwrite any existing baselines
     * and will create missing ones (equivalent to setting
     * `createMissingBaselines: true`).
     */
    updateBaselines?: boolean;
}
export declare class MugshotMissingBaselineError extends Error {
    constructor();
}
export default class Mugshot {
    private readonly browser;
    private readonly resultsPath;
    private readonly fs;
    private readonly pngDiffer;
    private readonly pngProcessor;
    private readonly screenshotter;
    private readonly createMissingBaselines;
    private updateBaselines;
    /**
     * @param browser
     * @param resultsPath
     * @param fs
     * @param pngDiffer
     * @param pngProcessor
     * @param screenshotter
     * @param createMissingBaselines Defaults to false in a CI env, true otherwise.
     * @param updateBaselines
     */
    constructor(browser: Browser, resultsPath: string, { fs, pngDiffer, pngProcessor, screenshotter, createMissingBaselines, updateBaselines }?: MugshotOptions);
    /**
     * Check for visual regressions.
     *
     * @param name Mugshot will look for a baseline named `${name}.png` in the
     *   `resultsPath` folder. If one is not found and `createMissingBaselines`
     *   is true then Mugshot will create a new baseline and pass the test. <br>
     *   If a baseline is found then it will be compared with the screenshot
     *   taken from `browser`. If differences are found the test will fail
     *   and a `${name}.diff.png` will be created in `resultsPath`.
     *
     * @param selector If given then Mugshot will screenshot the visible
     *   region bounded by the element's rectangle. <br>
     *   If the element is not in the viewport then, depending on the
     *   browser WebDriver implementation, a screenshot might fail.
     *   It is up to you to appropriately scroll the viewport
     *   before calling Mugshot. <br>
     *   If the element is not found an error will be thrown.
     *
     * @param options
     */
    check(name: string, selector: MugshotSelector, options?: ScreenshotOptions): Promise<MugshotResult>;
    check(name: string, options?: ScreenshotOptions): Promise<MugshotResult>;
    private writeBaseline;
    private diff;
    private getScreenshot;
}
export {};
